==> avscan_0.8.3-openssl.orig.tar.gz: avscan-0.8.3-openssl/avscan/wincb.h <==
#ifndef WINCB_H
#define WINCB_H

#include <gtk/gtk.h>
#include "win.h"


extern void WinScanListItemDestroyCB(gpointer data);
extern void WinResultsListItemDestroyCB(gpointer data);

extern gint WinEventCB(
	GtkWidget *widget, GdkEvent *event, gpointer data
);

extern gint WinOPIDEnterEventCB(
	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
);
extern gint WinOPIDLeaveEventCB(
	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
);

extern void WinToolBarItemCB(
	toolbar_item_struct *item, gint id, gpointer data
);
extern void WinToolBarItemEnterCB(
	toolbar_item_struct *item, gint id, gpointer data
);
extern void WinToolBarItemLeaveCB(
	toolbar_item_struct *item, gint id, gpointer data
);

extern void WinNotebookSwitchPageCB(
        GtkNotebook *notebook, GtkNotebookPage *page, guint page_num,
        gpointer data
);

extern gint WinEntryCompletePathKeyCB(
        GtkWidget *widget, GdkEventKey *key, gpointer data
);

extern gint WinListEventCB(GtkWidget *widget, GdkEvent *event, gpointer data);

extern void WinListResizeColumnCB(
	GtkCList *clist, gint column, gint width, gpointer data
);
extern void WinListClickColumnCB(
	GtkCList *clist, gint column, gpointer data 
);
extern void WinListSelectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data
);
extern void WinListUnselectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data                                           
);

extern void WinTreeSelectRowCB(
        GtkCTree *ctree, GtkCTreeNode *node, gint column,
        gpointer data
);
extern void WinTreeUnselectRowCB(
        GtkCTree *ctree, GtkCTreeNode *node, gint column,
        gpointer data
);
extern void WinTreeExpandCB(
        GtkCTree *ctree, GtkCTreeNode *node, gpointer data
);
extern void WinTreeCollapseCB(
        GtkCTree *ctree, GtkCTreeNode *node, gpointer data
);

extern void WinDBFindEntryCB(GtkWidget *widget, gpointer data);
extern gint WinDBTreeLoadStartIdleCB(gpointer data);

extern gint WinScanMonitorTOCB(gpointer data);
extern gint WinUpdateMonitorTOCB(gpointer data);


#endif	/* WINCB_H */

==> avscan_1.3.1-openssl.orig.tar.gz: avscan-1.3.1-openssl/avscan/wincb.h <==
#ifndef WINCB_H
#define WINCB_H

#include <gtk/gtk.h>
#include "win.h"


extern void WinScanListItemDestroyCB(gpointer data);
extern void WinResultsListItemDestroyCB(gpointer data);
extern void WinDBListItemDestroyCB(gpointer data);

extern gint WinEventCB(
	GtkWidget *widget, GdkEvent *event, gpointer data
);

extern gint WinOPIDEnterEventCB(
	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
);
extern gint WinOPIDLeaveEventCB(
	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
);

extern void WinToolBarItemCB(
	toolbar_item_struct *item, gint id, gpointer data
);
extern void WinToolBarItemEnterCB(
	toolbar_item_struct *item, gint id, gpointer data
);
extern void WinToolBarItemLeaveCB(
	toolbar_item_struct *item, gint id, gpointer data
);

extern void WinNotebookSwitchPageCB(
        GtkNotebook *notebook, GtkNotebookPage *page, guint page_num,
        gpointer data
);

extern void WinLocationEntryChangedCB(GtkWidget *widget, gpointer data);
extern gint WinEntryCompletePathKeyCB(
        GtkWidget *widget, GdkEventKey *key, gpointer data
);

extern gint WinListEventCB(GtkWidget *widget, GdkEvent *event, gpointer data);

extern void WinListResizeColumnCB(
	GtkCList *clist, gint column, gint width, gpointer data
);
extern void WinListClickColumnCB(
	GtkCList *clist, gint column, gpointer data 
);
extern void WinListSelectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data
);
extern void WinListUnselectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data                                           
);

extern void WinTreeSelectRowCB(
        GtkCTree *ctree, GtkCTreeNode *node, gint column,
        gpointer data
);
extern void WinTreeUnselectRowCB(
        GtkCTree *ctree, GtkCTreeNode *node, gint column,
        gpointer data
);
extern void WinTreeExpandCB(
        GtkCTree *ctree, GtkCTreeNode *node, gpointer data
);
extern void WinTreeCollapseCB(
        GtkCTree *ctree, GtkCTreeNode *node, gpointer data
);

extern void WinDBFindEntryCB(GtkWidget *widget, gpointer data);
extern gint WinDBTreeLoadStartIdleCB(gpointer data);

extern gint WinScanMonitorTOCB(gpointer data);
extern gint WinDBUpdateNetMonitorTOCB(gpointer data);


extern gint WinPatternDlgDeleteEventCB(
        GtkWidget *widget, GdkEvent *event, gpointer data
);
extern void WinPatternDlgCloseCB(GtkWidget *widget, gpointer data);


#endif	/* WINCB_H */
